disp("Testing {xls,ods}read...")

# Test defaults

testhelper("xls")
testhelper("xlsx")
testhelper("ods")
testhelper("gnumeric")

# Test specific interfaces (UNO must be last in each category)

testhelper("xls", "JXL")
testhelper("xls", "POI")
testhelper("xls", "UNO")

testhelper("xlsx", "OCT")
testhelper("xlsx", "POI")
testhelper("xlsx", "UNO")

testhelper("ods", "OCT")
testhelper("ods", "UNO")
